==> gpss-1.03-src.zip: jp/wda/gpss/SockletDeployInfo.java <==
package jp.wda.gpss;

import jp.wda.gpss.system.InitParamContainerImpl;

/**
 * Sockletz
 *
 * @version	1.00002	2003/05/22
 * @since		1.00002	2003/04/30
 * @author	amoi
 */
public class SockletDeployInfo extends InitParamContainerImpl {
	// RXgN^ ///////////////////////////////////////////////////////////////////
	//                                                                    Constructors //
	/////////////////////////////////////////////////////////////////////////////////////

	/* ***********************************************************************>> */;
	/**
	 * ftHg̐ݒpăIuWFNg\z܂B
	 */
	public SockletDeployInfo(){
		super();
	}

	/* ***********************************************************************>> */;
	/**
	 * Sockletzw肵ăIuWFNg\z܂B
	 *
	 * @param name T[oɓo^Sockletz
	 */
	public SockletDeployInfo(String name){
		super();
		
		setName(name);
	}

	// vpeB ///////////////////////////////////////////////////////////////////////
	//                                                                      Properties //
	/////////////////////////////////////////////////////////////////////////////////////

	/* ***********************************************************************>> */;
	/**
	 *	Sockletz<BR>
	 */
	private String name ;
	/**
	 *	Sockletz擾܂B<BR>
	 *	@return Sockletz
	 */
	public String getName(){ return name; }
	/**
	 *	Sockletzݒ肵܂B<BR>
	 *	@param s ݒl<BR>
	 */
	public void setName(String s){ name = s; }

	/* ***********************************************************************>> */;
	/**
	 *	NX<BR>
	 */
	private String classname ;
	/**
	 *	NX擾܂B<BR>
	 *	@return NX
	 */
	public String getClassname(){ return classname; }
	/**
	 *	NXݒ肵܂B<BR>
	 *	@param s ݒl<BR>
	 */
	public void setClassname(String s){ classname = s; }

	/* ***********************************************************************>> */;
	/**
	 *	^CAEg<BR>
	 */
	private int timeout;
	/**
	 *	^CAEg(~bP)擾܂B<BR>
	 *	@return ^CAEg(~bP)
	 */
	public int getTimeout(){ return timeout; }
	/**
	 *	^CAEg(~bP)ݒ肵܂B<BR>
	 *	@param s ݒl<BR>
	 */
	public void setTimeout(int s){ timeout = s; }

	/* ***********************************************************************>> */;
	/**
	 *	O擾[h<BR>
	 */
	private String logmode;
	/**
	 *	O擾[h擾܂B<BR>
	 *	@return O擾[h
	 */
	public String getLogMode(){ return logmode; }
	/**
	 *	O擾[hݒ肵܂B<BR>
	 *	@param s ݒl<BR>
	 */
	public void setLogMode(String s){
		if(s == null || s.length() == 0){
			logmode = "WARN";
		}else{
			logmode = s;
		}
	}

	/* ***********************************************************************>> */;
	/**
	 *	Ot@C<BR>
	 */
	private String logfile;
	/**
	 *	Ot@C擾܂B<BR>
	 *	@return Ot@C
	 */
	public String getLogFile(){ return logfile; }
	/**
	 *	Ot@Cݒ肵܂B<BR>
	 *	@param s ݒl<BR>
	 */
	public void setLogFile(String s){
		if(s == null || s.length() == 0){
			logfile = null;
		}else{
			logfile = s;
		}
	}

	/* ***********************************************************************>> */;
	/**
	 *	OGR[fBO<BR>
	 */
	private String logencoding;
	/**
	 *	OGR[fBO擾܂B<BR>
	 *	@return OGR[fBO
	 */
	public String getLogEncoding(){ return logencoding; }
	/**
	 *	OGR[fBOݒ肵܂B<BR>
	 *	@param s ݒl<BR>
	 */
	public void setLogEncoding(String s){
		if(s == null || s.length() == 0){
			logencoding = "UTF-8";
		}else{
			logencoding = s;
		}
	}

	/* ***********************************************************************>> */;
	/**
	 *	O擾`<BR>
	 */
	private String logpattern;
	/**
	 *	O擾`擾܂B<BR>
	 *	@return O擾`
	 */
	public String getLogPattern(){ return logpattern; }
	/**
	 *	O擾`ݒ肵܂B<BR>
	 *	@param s ݒl<BR>
	 */
	public void setLogPattern(String s){
		if(s == null || s.length() == 0){
			logpattern = "[%d{yyyy/MM/dd HH:mm:ss}] %m%n";
		}else{
			logpattern = s;
		}
	}

	// CX^X\bh /////////////////////////////////////////////////////////////
	//                                                                Instance Methods //
	/////////////////////////////////////////////////////////////////////////////////////

	/* ***********************************************************************>> */;
	/**
	 * Sockletzݒ肵܂B<BR>
	 * @param name Sockletz
	 * @param classname NX
	 * @param timeout ^CAEg(~bP)
	 */
	public void setInformation(String name, String classname, String timeout){
		setName(name);
		setClassname(classname);
		
		int tout = 0;
		try{
			tout = Integer.parseInt(timeout);
		}catch(Throwable e){
			tout = 0;
		}
		setTimeout(tout);
	}
	
	/**
	 * log4jO擾ݒ肵܂B
	 * 
	 * @param mode O擾[h
	 * @param file Ot@C
	 * @param encoding OGR[fBO
	 * @param layoutPattern O擾`
	 */
	public void setLoggerInfo(String mode, String file, String encoding, String layoutPattern){
		setLogMode(mode);
		setLogFile(file);
		setLogEncoding(encoding);
		setLogPattern(layoutPattern);
	}
}

==> gpss-1.04.02-src.zip: jp/wda/gpss/SockletDeployInfo.java <==
package jp.wda.gpss;

import jp.wda.gpss.system.Configuration;
import jp.wda.gpss.system.InitParamContainerImpl;

/**
 * Sockletz
 *
 * @version	1.04		2003/11/27
 * @since		1.00002	2003/04/30
 * @author	amoi
 */
public class SockletDeployInfo extends InitParamContainerImpl {
	// RXgN^ ///////////////////////////////////////////////////////////////////
	//                                                                    Constructors //
	/////////////////////////////////////////////////////////////////////////////////////

	/* ***********************************************************************>> */;
	/**
	 * ftHg̐ݒpăIuWFNg\z܂B
	 */
	public SockletDeployInfo(){
		super();
	}

	/* ***********************************************************************>> */;
	/**
	 * Sockletzw肵ăIuWFNg\z܂B
	 *
	 * @param name T[oɓo^Sockletz
	 */
	public SockletDeployInfo(String name){
		super();
		
		setName(name);
	}

	// vpeB ///////////////////////////////////////////////////////////////////////
	//                                                                      Properties //
	/////////////////////////////////////////////////////////////////////////////////////

	/* ***********************************************************************>> */;
	/**
	 *	Sockletz<BR>
	 */
	private String name ;
	/**
	 *	Sockletz擾܂B<BR>
	 *	@return Sockletz
	 */
	public String getName(){ return name; }
	/**
	 *	Sockletzݒ肵܂B<BR>
	 *	@param s ݒl<BR>
	 */
	public void setName(String s){ name = s; }

	/* ***********************************************************************>> */;
	/**
	 *	NX<BR>
	 */
	private String classname ;
	/**
	 *	NX擾܂B<BR>
	 *	@return NX
	 */
	public String getClassname(){ return classname; }
	/**
	 *	NXݒ肵܂B<BR>
	 *	@param s ݒl<BR>
	 */
	public void setClassname(String s){ classname = s; }

	/* ***********************************************************************>> */;
	/**
	 *	^CAEg<BR>
	 */
	private int timeout;
	/**
	 *	^CAEg(~bP)擾܂B<BR>
	 *	@return ^CAEg(~bP)
	 */
	public int getTimeout(){ return timeout; }
	/**
	 *	^CAEg(~bP)ݒ肵܂B<BR>
	 *	@param s ݒl<BR>
	 */
	public void setTimeout(int s){ timeout = s; }

	/* ***********************************************************************>> */;
	/**
	 *	O擾[h<BR>
	 */
	private String logmode;
	/**
	 *	O擾[h擾܂B<BR>
	 *	@return O擾[h
	 */
	public String getLogMode(){ return logmode; }
	/**
	 *	O擾[hݒ肵܂B<BR>
	 *	@param s ݒl<BR>
	 */
	public void setLogMode(String s){
		if(s == null || s.length() == 0){
			logmode = "WARN";
		}else{
			logmode = s;
		}
	}

	/* ***********************************************************************>> */;
	/**
	 *	Ot@C<BR>
	 */
	private String logfile;
	/**
	 *	Ot@C擾܂B<BR>
	 *	@return Ot@C
	 */
	public String getLogFile(){ return logfile; }
	/**
	 *	Ot@Cݒ肵܂B<BR>
	 *	@param s ݒl<BR>
	 */
	public void setLogFile(String s){
		if(s == null || s.length() == 0){
			logfile = null;
			return;
		}
		
		logfile = Configuration.getAbsolutePath(s).getAbsolutePath();
	}

	/* ***********************************************************************>> */;
	/**
	 *	OGR[fBO<BR>
	 */
	private String logencoding;
	/**
	 *	OGR[fBO擾܂B<BR>
	 *	@return OGR[fBO
	 */
	public String getLogEncoding(){ return logencoding; }
	/**
	 *	OGR[fBOݒ肵܂B<BR>
	 *	@param s ݒl<BR>
	 */
	public void setLogEncoding(String s){
		if(s == null || s.length() == 0){
			logencoding = "UTF-8";
		}else{
			logencoding = s;
		}
	}

	/* ***********************************************************************>> */;
	/**
	 *	O擾`<BR>
	 */
	private String logpattern;
	/**
	 *	O擾`擾܂B<BR>
	 *	@return O擾`
	 */
	public String getLogPattern(){ return logpattern; }
	/**
	 *	O擾`ݒ肵܂B<BR>
	 *	@param s ݒl<BR>
	 */
	public void setLogPattern(String s){
		if(s == null || s.length() == 0){
			logpattern = "[%d{yyyy/MM/dd HH:mm:ss}] %m%n";
		}else{
			logpattern = s;
		}
	}

	// CX^X\bh /////////////////////////////////////////////////////////////
	//                                                                Instance Methods //
	/////////////////////////////////////////////////////////////////////////////////////

	/* ***********************************************************************>> */;
	/**
	 * Sockletzݒ肵܂B<BR>
	 * @param name Sockletz
	 * @param classname NX
	 * @param timeout ^CAEg(~bP)
	 */
	public void setInformation(String name, String classname, String timeout){
		setName(name);
		setClassname(classname);
		
		int tout = 0;
		try{
			tout = Integer.parseInt(timeout);
		}catch(Throwable e){
			tout = 0;
		}
		setTimeout(tout);
	}
	
	/**
	 * log4jO擾ݒ肵܂B
	 * 
	 * @param mode O擾[h
	 * @param file Ot@C
	 * @param encoding OGR[fBO
	 * @param layoutPattern O擾`
	 */
	public void setLoggerInfo(String mode, String file, String encoding, String layoutPattern){
		setLogMode(mode);
		setLogFile(file);
		setLogEncoding(encoding);
		setLogPattern(layoutPattern);
	}
}
